# IO.Swagger - the C# library for the Lightning - A Weather Source API

**This API is in BETA release.**  Global lightning archive, updated in real time. The Weather Source Lightning API provides the most accurate and reliable global lightning data available. All matching lightning events within 12 km (7 miles) of a provided location (and within the provided time range) are returned. The global lightning archive is available from the years 2021 and onward.  **IMPORTANT:** To authenticate to the Weather Source Lightning API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 

This C# SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.0.0
- SDK version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.dotnet.CSharpClientCodegen
    For more information, please visit [https://developer.weathersourceapis.com/](https://developer.weathersourceapis.com/)

<a name="frameworks-supported"></a>
## Frameworks supported
- .NET 4.0 or later
- Windows Phone 7.1 (Mango)

<a name="dependencies"></a>
## Dependencies
- [RestSharp](https://www.nuget.org/packages/RestSharp) - 105.1.0 or later
- [Json.NET](https://www.nuget.org/packages/Newtonsoft.Json/) - 7.0.0 or later
- [JsonSubTypes](https://www.nuget.org/packages/JsonSubTypes/) - 1.2.0 or later

The DLLs included in the package may not be the latest version. We recommend using [NuGet](https://docs.nuget.org/consume/installing-nuget) to obtain the latest version of the packages:
```
Install-Package RestSharp
Install-Package Newtonsoft.Json
Install-Package JsonSubTypes
```

NOTE: RestSharp versions greater than 105.1.0 have a bug which causes file uploads to fail. See [RestSharp#742](https://github.com/restsharp/RestSharp/issues/742)

<a name="installation"></a>
## Installation
Run the following command to generate the DLL
- [Mac/Linux] `/bin/sh build.sh`
- [Windows] `build.bat`

Then include the DLL (under the `bin` folder) in the C# project, and use the namespaces:
```csharp
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;
```
<a name="packaging"></a>
## Packaging

A `.nuspec` is included with the project. You can follow the Nuget quickstart to [create](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#create-the-package) and [publish](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#publish-the-package) packages.

This `.nuspec` uses placeholders from the `.csproj`, so build the `.csproj` directly:

```
nuget pack -Build -OutputDirectory out IO.Swagger.csproj
```

Then, publish to a [local feed](https://docs.microsoft.com/en-us/nuget/hosting-packages/local-feeds) or [other host](https://docs.microsoft.com/en-us/nuget/hosting-packages/overview) and consume the new package via Nuget as usual.

<a name="getting-started"></a>
## Getting Started

```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class Example
    {
        public void main()
        {
            // Configure API key authorization: ApiKeyAuth
            Configuration.Default.ApiKey.Add("X-API-KEY", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // Configuration.Default.ApiKeyPrefix.Add("X-API-KEY", "Bearer");

            var apiInstance = new OnpointsApi();
            var onpointId = 56;  // int? | An OnPoint™ ID.
            var timestampStart = 2013-10-20T19:20:30+01:00;  // DateTime? | A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
            var timestampEnd = 2013-10-20T19:20:30+01:00;  // DateTime? | A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
            var fields = new List<string>(); // List<string> | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.** 
            var unitScale = unitScale_example;  // string | The unit scale for returned values.<br> (optional)  (default to IMPERIAL)
            var limit = 56;  // int? | Limit the number of matching events returned. Returned events are ordered by distance from the provided location. Applying a limit will return the nearest events. A value of 0 means no limit.  (optional)  (default to 0)

            try
            {
                // Lightning data proximate to an OnPoint™ point.
                LightningOnpointObj result = apiInstance.OnpointsOnpointIdPeriodTimestampStarttimestampEndGet(onpointId, timestampStart, timestampEnd, fields, unitScale, limit);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling OnpointsApi.OnpointsOnpointIdPeriodTimestampStarttimestampEndGet: " + e.Message );
            }
        }
    }
}
```

<a name="documentation-for-api-endpoints"></a>
## Documentation for API Endpoints

All URIs are relative to *https://lightning.weathersourceapis.com/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*OnpointsApi* | [**OnpointsOnpointIdPeriodTimestampStarttimestampEndGet**](docs/OnpointsApi.md#onpointsonpointidperiodtimestampstarttimestampendget) | **GET** /onpoints/{onpointId}/period/{timestampStart},{timestampEnd} | Lightning data proximate to an OnPoint™ point.
*PointsApi* | [**PointsLatitudelongitudePeriodTimestampStarttimestampEndGet**](docs/PointsApi.md#pointslatitudelongitudeperiodtimestampstarttimestampendget) | **GET** /points/{latitude},{longitude}/period/{timestampStart},{timestampEnd} | Lightning data proximate to a Latitude/Longitude point.

<a name="documentation-for-models"></a>
## Documentation for Models

 - [Model.BoundingPoints](docs/BoundingPoints.md)
 - [Model.BoundingPointsInner](docs/BoundingPointsInner.md)
 - [Model.ErrorObj](docs/ErrorObj.md)
 - [Model.FieldListObj](docs/FieldListObj.md)
 - [Model.Fields](docs/Fields.md)
 - [Model.Grid](docs/Grid.md)
 - [Model.LightningArr](docs/LightningArr.md)
 - [Model.LightningObj](docs/LightningObj.md)
 - [Model.LightningOnpointObj](docs/LightningOnpointObj.md)
 - [Model.LightningPointObj](docs/LightningPointObj.md)
 - [Model.OnpointObj](docs/OnpointObj.md)
 - [Model.PointObj](docs/PointObj.md)

<a name="documentation-for-authorization"></a>
## Documentation for Authorization

<a name="ApiKeyAuth"></a>
### ApiKeyAuth

- **Type**: API key
- **API key parameter name**: X-API-KEY
- **Location**: HTTP header

