/* 
 * Lightning - A Weather Source API
 *
 * **This API is in BETA release.**  Global lightning archive, updated in real time. The Weather Source Lightning API provides the most accurate and reliable global lightning data available. All matching lightning events within 12 km (7 miles) of a provided location (and within the provided time range) are returned. The global lightning archive is available from the years 2021 and onward.  **IMPORTANT:** To authenticate to the Weather Source Lightning API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
 *
 * OpenAPI spec version: 2.0.0
 * Contact: support@weathersource.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 */
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
        public interface IOnpointsApi : IApiAccessor
    {
        #region Synchronous Operations
        /// <summary>
        /// Lightning data proximate to an OnPoint™ point.
        /// </summary>
        /// <remarks>
        /// Returns all lightning events that are both within 12 km (7 miles) of a provided OnPoint™ point and within the provided time range. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Nowcast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="onpointId">An OnPoint™ ID.</param>
        /// <param name="timestampStart">A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.</param>
        /// <param name="timestampEnd">A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.</param>
        /// <param name="fields">A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.** </param>
        /// <param name="unitScale">The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)</param>
        /// <param name="limit">Limit the number of matching events returned. Returned events are ordered by distance from the provided location. Applying a limit will return the nearest events. A value of 0 means no limit.  (optional, default to 0)</param>
        /// <returns>LightningOnpointObj</returns>
        LightningOnpointObj OnpointsOnpointIdPeriodTimestampStarttimestampEndGet (int? onpointId, DateTime? timestampStart, DateTime? timestampEnd, List<string> fields, string unitScale = null, int? limit = null);

        /// <summary>
        /// Lightning data proximate to an OnPoint™ point.
        /// </summary>
        /// <remarks>
        /// Returns all lightning events that are both within 12 km (7 miles) of a provided OnPoint™ point and within the provided time range. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Nowcast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="onpointId">An OnPoint™ ID.</param>
        /// <param name="timestampStart">A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.</param>
        /// <param name="timestampEnd">A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.</param>
        /// <param name="fields">A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.** </param>
        /// <param name="unitScale">The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)</param>
        /// <param name="limit">Limit the number of matching events returned. Returned events are ordered by distance from the provided location. Applying a limit will return the nearest events. A value of 0 means no limit.  (optional, default to 0)</param>
        /// <returns>ApiResponse of LightningOnpointObj</returns>
        ApiResponse<LightningOnpointObj> OnpointsOnpointIdPeriodTimestampStarttimestampEndGetWithHttpInfo (int? onpointId, DateTime? timestampStart, DateTime? timestampEnd, List<string> fields, string unitScale = null, int? limit = null);
        #endregion Synchronous Operations
        #region Asynchronous Operations
        /// <summary>
        /// Lightning data proximate to an OnPoint™ point.
        /// </summary>
        /// <remarks>
        /// Returns all lightning events that are both within 12 km (7 miles) of a provided OnPoint™ point and within the provided time range. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Nowcast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="onpointId">An OnPoint™ ID.</param>
        /// <param name="timestampStart">A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.</param>
        /// <param name="timestampEnd">A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.</param>
        /// <param name="fields">A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.** </param>
        /// <param name="unitScale">The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)</param>
        /// <param name="limit">Limit the number of matching events returned. Returned events are ordered by distance from the provided location. Applying a limit will return the nearest events. A value of 0 means no limit.  (optional, default to 0)</param>
        /// <returns>Task of LightningOnpointObj</returns>
        System.Threading.Tasks.Task<LightningOnpointObj> OnpointsOnpointIdPeriodTimestampStarttimestampEndGetAsync (int? onpointId, DateTime? timestampStart, DateTime? timestampEnd, List<string> fields, string unitScale = null, int? limit = null);

        /// <summary>
        /// Lightning data proximate to an OnPoint™ point.
        /// </summary>
        /// <remarks>
        /// Returns all lightning events that are both within 12 km (7 miles) of a provided OnPoint™ point and within the provided time range. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Nowcast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="onpointId">An OnPoint™ ID.</param>
        /// <param name="timestampStart">A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.</param>
        /// <param name="timestampEnd">A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.</param>
        /// <param name="fields">A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.** </param>
        /// <param name="unitScale">The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)</param>
        /// <param name="limit">Limit the number of matching events returned. Returned events are ordered by distance from the provided location. Applying a limit will return the nearest events. A value of 0 means no limit.  (optional, default to 0)</param>
        /// <returns>Task of ApiResponse (LightningOnpointObj)</returns>
        System.Threading.Tasks.Task<ApiResponse<LightningOnpointObj>> OnpointsOnpointIdPeriodTimestampStarttimestampEndGetAsyncWithHttpInfo (int? onpointId, DateTime? timestampStart, DateTime? timestampEnd, List<string> fields, string unitScale = null, int? limit = null);
        #endregion Asynchronous Operations
    }

    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
        public partial class OnpointsApi : IOnpointsApi
    {
        private IO.Swagger.Client.ExceptionFactory _exceptionFactory = (name, response) => null;

        /// <summary>
        /// Initializes a new instance of the <see cref="OnpointsApi"/> class.
        /// </summary>
        /// <returns></returns>
        public OnpointsApi(String basePath)
        {
            this.Configuration = new IO.Swagger.Client.Configuration { BasePath = basePath };

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="OnpointsApi"/> class
        /// </summary>
        /// <returns></returns>
        public OnpointsApi()
        {
            this.Configuration = IO.Swagger.Client.Configuration.Default;

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="OnpointsApi"/> class
        /// using Configuration object
        /// </summary>
        /// <param name="configuration">An instance of Configuration</param>
        /// <returns></returns>
        public OnpointsApi(IO.Swagger.Client.Configuration configuration = null)
        {
            if (configuration == null) // use the default one in Configuration
                this.Configuration = IO.Swagger.Client.Configuration.Default;
            else
                this.Configuration = configuration;

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;
        }

        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        public String GetBasePath()
        {
            return this.Configuration.ApiClient.RestClient.BaseUrl.ToString();
        }

        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        [Obsolete("SetBasePath is deprecated, please do 'Configuration.ApiClient = new ApiClient(\"http://new-path\")' instead.")]
        public void SetBasePath(String basePath)
        {
            // do nothing
        }

        /// <summary>
        /// Gets or sets the configuration object
        /// </summary>
        /// <value>An instance of the Configuration</value>
        public IO.Swagger.Client.Configuration Configuration {get; set;}

        /// <summary>
        /// Provides a factory method hook for the creation of exceptions.
        /// </summary>
        public IO.Swagger.Client.ExceptionFactory ExceptionFactory
        {
            get
            {
                if (_exceptionFactory != null && _exceptionFactory.GetInvocationList().Length > 1)
                {
                    throw new InvalidOperationException("Multicast delegate for ExceptionFactory is unsupported.");
                }
                return _exceptionFactory;
            }
            set { _exceptionFactory = value; }
        }

        /// <summary>
        /// Gets the default header.
        /// </summary>
        /// <returns>Dictionary of HTTP header</returns>
        [Obsolete("DefaultHeader is deprecated, please use Configuration.DefaultHeader instead.")]
        public IDictionary<String, String> DefaultHeader()
        {
            return new ReadOnlyDictionary<string, string>(this.Configuration.DefaultHeader);
        }

        /// <summary>
        /// Add default header.
        /// </summary>
        /// <param name="key">Header field name.</param>
        /// <param name="value">Header field value.</param>
        /// <returns></returns>
        [Obsolete("AddDefaultHeader is deprecated, please use Configuration.AddDefaultHeader instead.")]
        public void AddDefaultHeader(string key, string value)
        {
            this.Configuration.AddDefaultHeader(key, value);
        }

        /// <summary>
        /// Lightning data proximate to an OnPoint™ point. Returns all lightning events that are both within 12 km (7 miles) of a provided OnPoint™ point and within the provided time range. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Nowcast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="onpointId">An OnPoint™ ID.</param>
        /// <param name="timestampStart">A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.</param>
        /// <param name="timestampEnd">A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.</param>
        /// <param name="fields">A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.** </param>
        /// <param name="unitScale">The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)</param>
        /// <param name="limit">Limit the number of matching events returned. Returned events are ordered by distance from the provided location. Applying a limit will return the nearest events. A value of 0 means no limit.  (optional, default to 0)</param>
        /// <returns>LightningOnpointObj</returns>
        public LightningOnpointObj OnpointsOnpointIdPeriodTimestampStarttimestampEndGet (int? onpointId, DateTime? timestampStart, DateTime? timestampEnd, List<string> fields, string unitScale = null, int? limit = null)
        {
             ApiResponse<LightningOnpointObj> localVarResponse = OnpointsOnpointIdPeriodTimestampStarttimestampEndGetWithHttpInfo(onpointId, timestampStart, timestampEnd, fields, unitScale, limit);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Lightning data proximate to an OnPoint™ point. Returns all lightning events that are both within 12 km (7 miles) of a provided OnPoint™ point and within the provided time range. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Nowcast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="onpointId">An OnPoint™ ID.</param>
        /// <param name="timestampStart">A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.</param>
        /// <param name="timestampEnd">A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.</param>
        /// <param name="fields">A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.** </param>
        /// <param name="unitScale">The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)</param>
        /// <param name="limit">Limit the number of matching events returned. Returned events are ordered by distance from the provided location. Applying a limit will return the nearest events. A value of 0 means no limit.  (optional, default to 0)</param>
        /// <returns>ApiResponse of LightningOnpointObj</returns>
        public ApiResponse< LightningOnpointObj > OnpointsOnpointIdPeriodTimestampStarttimestampEndGetWithHttpInfo (int? onpointId, DateTime? timestampStart, DateTime? timestampEnd, List<string> fields, string unitScale = null, int? limit = null)
        {
            // verify the required parameter 'onpointId' is set
            if (onpointId == null)
                throw new ApiException(400, "Missing required parameter 'onpointId' when calling OnpointsApi->OnpointsOnpointIdPeriodTimestampStarttimestampEndGet");
            // verify the required parameter 'timestampStart' is set
            if (timestampStart == null)
                throw new ApiException(400, "Missing required parameter 'timestampStart' when calling OnpointsApi->OnpointsOnpointIdPeriodTimestampStarttimestampEndGet");
            // verify the required parameter 'timestampEnd' is set
            if (timestampEnd == null)
                throw new ApiException(400, "Missing required parameter 'timestampEnd' when calling OnpointsApi->OnpointsOnpointIdPeriodTimestampStarttimestampEndGet");
            // verify the required parameter 'fields' is set
            if (fields == null)
                throw new ApiException(400, "Missing required parameter 'fields' when calling OnpointsApi->OnpointsOnpointIdPeriodTimestampStarttimestampEndGet");

            var localVarPath = "/onpoints/{onpointId}/period/{timestampStart},{timestampEnd}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (onpointId != null) localVarPathParams.Add("onpointId", this.Configuration.ApiClient.ParameterToString(onpointId)); // path parameter
            if (timestampStart != null) localVarPathParams.Add("timestampStart", this.Configuration.ApiClient.ParameterToString(timestampStart)); // path parameter
            if (timestampEnd != null) localVarPathParams.Add("timestampEnd", this.Configuration.ApiClient.ParameterToString(timestampEnd)); // path parameter
            if (fields != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("csv", "fields", fields)); // query parameter
            if (unitScale != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "unitScale", unitScale)); // query parameter
            if (limit != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "limit", limit)); // query parameter
            // authentication (ApiKeyAuth) required
            if (!String.IsNullOrEmpty(this.Configuration.GetApiKeyWithPrefix("X-API-KEY")))
            {
                localVarHeaderParams["X-API-KEY"] = this.Configuration.GetApiKeyWithPrefix("X-API-KEY");
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("OnpointsOnpointIdPeriodTimestampStarttimestampEndGet", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<LightningOnpointObj>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (LightningOnpointObj) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(LightningOnpointObj)));
        }

        /// <summary>
        /// Lightning data proximate to an OnPoint™ point. Returns all lightning events that are both within 12 km (7 miles) of a provided OnPoint™ point and within the provided time range. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Nowcast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="onpointId">An OnPoint™ ID.</param>
        /// <param name="timestampStart">A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.</param>
        /// <param name="timestampEnd">A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.</param>
        /// <param name="fields">A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.** </param>
        /// <param name="unitScale">The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)</param>
        /// <param name="limit">Limit the number of matching events returned. Returned events are ordered by distance from the provided location. Applying a limit will return the nearest events. A value of 0 means no limit.  (optional, default to 0)</param>
        /// <returns>Task of LightningOnpointObj</returns>
        public async System.Threading.Tasks.Task<LightningOnpointObj> OnpointsOnpointIdPeriodTimestampStarttimestampEndGetAsync (int? onpointId, DateTime? timestampStart, DateTime? timestampEnd, List<string> fields, string unitScale = null, int? limit = null)
        {
             ApiResponse<LightningOnpointObj> localVarResponse = await OnpointsOnpointIdPeriodTimestampStarttimestampEndGetAsyncWithHttpInfo(onpointId, timestampStart, timestampEnd, fields, unitScale, limit);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Lightning data proximate to an OnPoint™ point. Returns all lightning events that are both within 12 km (7 miles) of a provided OnPoint™ point and within the provided time range. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Nowcast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="onpointId">An OnPoint™ ID.</param>
        /// <param name="timestampStart">A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.</param>
        /// <param name="timestampEnd">A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.</param>
        /// <param name="fields">A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.** </param>
        /// <param name="unitScale">The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)</param>
        /// <param name="limit">Limit the number of matching events returned. Returned events are ordered by distance from the provided location. Applying a limit will return the nearest events. A value of 0 means no limit.  (optional, default to 0)</param>
        /// <returns>Task of ApiResponse (LightningOnpointObj)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<LightningOnpointObj>> OnpointsOnpointIdPeriodTimestampStarttimestampEndGetAsyncWithHttpInfo (int? onpointId, DateTime? timestampStart, DateTime? timestampEnd, List<string> fields, string unitScale = null, int? limit = null)
        {
            // verify the required parameter 'onpointId' is set
            if (onpointId == null)
                throw new ApiException(400, "Missing required parameter 'onpointId' when calling OnpointsApi->OnpointsOnpointIdPeriodTimestampStarttimestampEndGet");
            // verify the required parameter 'timestampStart' is set
            if (timestampStart == null)
                throw new ApiException(400, "Missing required parameter 'timestampStart' when calling OnpointsApi->OnpointsOnpointIdPeriodTimestampStarttimestampEndGet");
            // verify the required parameter 'timestampEnd' is set
            if (timestampEnd == null)
                throw new ApiException(400, "Missing required parameter 'timestampEnd' when calling OnpointsApi->OnpointsOnpointIdPeriodTimestampStarttimestampEndGet");
            // verify the required parameter 'fields' is set
            if (fields == null)
                throw new ApiException(400, "Missing required parameter 'fields' when calling OnpointsApi->OnpointsOnpointIdPeriodTimestampStarttimestampEndGet");

            var localVarPath = "/onpoints/{onpointId}/period/{timestampStart},{timestampEnd}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (onpointId != null) localVarPathParams.Add("onpointId", this.Configuration.ApiClient.ParameterToString(onpointId)); // path parameter
            if (timestampStart != null) localVarPathParams.Add("timestampStart", this.Configuration.ApiClient.ParameterToString(timestampStart)); // path parameter
            if (timestampEnd != null) localVarPathParams.Add("timestampEnd", this.Configuration.ApiClient.ParameterToString(timestampEnd)); // path parameter
            if (fields != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("csv", "fields", fields)); // query parameter
            if (unitScale != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "unitScale", unitScale)); // query parameter
            if (limit != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "limit", limit)); // query parameter
            // authentication (ApiKeyAuth) required
            if (!String.IsNullOrEmpty(this.Configuration.GetApiKeyWithPrefix("X-API-KEY")))
            {
                localVarHeaderParams["X-API-KEY"] = this.Configuration.GetApiKeyWithPrefix("X-API-KEY");
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("OnpointsOnpointIdPeriodTimestampStarttimestampEndGet", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<LightningOnpointObj>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (LightningOnpointObj) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(LightningOnpointObj)));
        }

    }
}
